@@ -1,17 +1,17 @@
 # pylint: disable = import-outside-toplevel
+from __future__ import annotations
 
 import sys
-from typing import List, Union
 
 from pydocstringformatter.utils.exceptions import (
     ParsingError,
     PydocstringFormatterError,
 )
 
-__version__ = "0.5.2"
+__version__ = "0.6.0"
 
 
-def run_docstring_formatter(argv: Union[List[str], None] = None) -> None:
+def run_docstring_formatter(argv: list[str] | None = None) -> None:
     """Run the formatter."""
     from pydocstringformatter.run import _Run
 
