@@ -1,9 +1,10 @@
+from __future__ import annotations
+
 import argparse
-from typing import List
 
 
 def _parse_command_line_arguments(
-    parser: argparse.ArgumentParser, namespace: argparse.Namespace, args: List[str]
+    parser: argparse.ArgumentParser, namespace: argparse.Namespace, args: list[str]
 ) -> None:
     """Parse all arguments on the provided argument parser."""
     parser.parse_known_args(args, namespace)
