@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 __all__ = ["FORMATTERS", "Formatter"]
 
-from typing import List
 
 from pydocstringformatter.formatting.base import Formatter
 from pydocstringformatter.formatting.formatter import (
@@ -8,6 +9,7 @@ from pydocstringformatter.formatting.formatter import (
     CapitalizeFirstLetterFormatter,
     ClosingQuotesFormatter,
     FinalPeriodFormatter,
+    LineWrapperFormatter,
     QuotesTypeFormatter,
     SplitSummaryAndDocstringFormatter,
     StripWhitespacesFormatter,
@@ -18,9 +20,10 @@ from pydocstringformatter.formatting.formatter import (
 #   String manipulation such as adding extra new lines
 #   Determine if multi-line or single line and position quotes accordingly
 #   String manipulation in which being multi-line or single line matters
-FORMATTERS: List[Formatter] = [
-    SplitSummaryAndDocstringFormatter(),
+FORMATTERS: list[Formatter] = [
     StripWhitespacesFormatter(),
+    SplitSummaryAndDocstringFormatter(),
+    LineWrapperFormatter(),
     BeginningQuotesFormatter(),
     ClosingQuotesFormatter(),
     CapitalizeFirstLetterFormatter(),
