@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import abc
 import argparse
+import functools
 import re
 import tokenize
 from typing import Literal
@@ -97,13 +100,59 @@ class StringAndQuotesFormatter(Formatter):
         )
 
 
-class SummaryFormatter(StringAndQuotesFormatter):
-    """Base class for formatter that only modifies the summary of a docstring."""
+class SummaryAndDescriptionFormatter(StringAndQuotesFormatter):
+    """Base class for formatter that modifies the summary and description."""
 
     @abc.abstractmethod
-    def _treat_summary(self, summary: str, indent_length: int) -> str:
+    def _treat_summary(
+        self,
+        summary: str,
+        indent_length: int,
+        quotes_length: Literal[1, 3],
+        description_exists: bool,
+    ) -> str:
         """Return a modified summary."""
 
+    @abc.abstractmethod
+    def _treat_description(self, description: str, indent_length: int) -> str:
+        """Return a modified description."""
+
+    @staticmethod
+    @functools.lru_cache(maxsize=None)
+    def _separate_summary_and_description(
+        docstring: str, indent_length: int, quotes_length: Literal[1, 3]
+    ) -> tuple[str, str, str | None]:
+        """Split the summary and description and handle quotes and indentation."""
+        if "\n\n" in docstring:
+            summary, description = docstring.split("\n\n", maxsplit=1)
+
+            # Remove final indentation, ending quotes and new line
+            description = description[:-quotes_length]
+            if indent_length and description.endswith(indent_length * " "):
+                description = description[:-indent_length]
+            if description.endswith("\n"):
+                description = description[:-1]
+        else:
+            summary, description = docstring, None
+
+            # Remove final indentation, ending quotes and new line
+            summary = summary[:-quotes_length]
+            if indent_length and summary.endswith(indent_length * " "):
+                summary = summary[:-indent_length]
+            if summary.endswith("\n"):
+                summary = summary[:-1]
+
+        # Remove opening quotes
+        summary = summary[quotes_length:]
+
+        # Prefix is the new-line + indentation for summaries that
+        # are not on the same line as the opening quotes
+        prefix = ""
+        if summary.startswith("\n"):
+            prefix = "\n" + indent_length * " "
+            summary = summary[1 + indent_length :]
+        return prefix, summary, description
+
     def _treat_string(
         self,
         tokeninfo: tokenize.TokenInfo,
@@ -111,24 +160,39 @@ class SummaryFormatter(StringAndQuotesFormatter):
         quotes: str,
         quotes_length: Literal[1, 3],
     ) -> str:
-        """Return a modified string."""
-        # TODO(#67): Handle identation at the end of a summary a little better
+        prefix, summary, description = self._separate_summary_and_description(
+            tokeninfo.string,
+            indent_length,
+            quotes_length,
+        )
 
-        # Split summary and description
-        if "\n\n" in tokeninfo.string:
-            summary, description = tokeninfo.string.split("\n\n", maxsplit=1)
-            description = description[:-quotes_length]
-        else:
-            summary, description = tokeninfo.string, None
-            summary = summary[:-quotes_length]
+        new_summary = self._treat_summary(
+            summary, indent_length, quotes_length, bool(description)
+        )
+        docstring = f"{quotes}{prefix}{new_summary}"
 
-        # Remove opening quotes
-        summary = summary[quotes_length:]
-
-        new_summary = self._treat_summary(summary, indent_length)
-
-        # Re-compose docstring
-        docstring = f"{quotes}{new_summary}"
         if description:
-            docstring += f"\n\n{description}"
+            new_description = self._treat_description(description, indent_length)
+            docstring += f"\n\n{new_description}"
+
+        # Determine whether ending quotes were initially on same or new line
+        if tokeninfo.string.splitlines()[-1] == indent_length * " " + quotes:
+            return f"{docstring}\n{indent_length * ' '}{quotes}"
         return f"{docstring}{quotes}"
+
+
+class SummaryFormatter(SummaryAndDescriptionFormatter):
+    """Base class for formatter that only modifies the summary of a docstring."""
+
+    @abc.abstractmethod
+    def _treat_summary(
+        self,
+        summary: str,
+        indent_length: int,
+        quotes_length: Literal[1, 3],
+        description_exists: bool,
+    ) -> str:
+        """Return a modified summary."""
+
+    def _treat_description(self, description: str, indent_length: int) -> str:
+        return description
