@@ -1,7 +1,11 @@
+from __future__ import annotations
+
 import re
+import textwrap
 import tokenize
 from typing import Literal
 
+from pydocstringformatter.formatting import _utils
 from pydocstringformatter.formatting.base import (
     StringAndQuotesFormatter,
     StringFormatter,
@@ -54,6 +58,63 @@ class CapitalizeFirstLetterFormatter(StringFormatter):
         return new_string or tokeninfo.string
 
 
+class LineWrapperFormatter(SummaryFormatter):
+    """Linewrap the docstring by the pre-defined line length."""
+
+    name = "linewrap-full-docstring"
+    optional = True
+
+    def _treat_summary(
+        self,
+        summary: str,
+        indent_length: int,
+        quotes_length: Literal[1, 3],
+        description_exists: bool,
+    ) -> str:
+        """Wrap the summary of a docstring."""
+
+        line_length = self.config.max_line_length
+
+        # Without a description we need to consider the length including closing quotes
+        if not description_exists:
+
+            # Calculate length without the ending quotes
+            length_without_ending = indent_length + quotes_length + len(summary)
+
+            # If potential length is less than line length we need to consider ending
+            # quotes as well for the line length
+            if length_without_ending < line_length:
+                # We subtract one more because we don't want a new line with just the
+                # ending quotes
+                line_length -= quotes_length + 1
+
+        summary_lines = summary.splitlines()
+
+        new_summary = "\n".join(
+            textwrap.wrap(
+                summary_lines[0],
+                width=line_length,
+                initial_indent=" " * (indent_length + quotes_length),
+                subsequent_indent=" " * indent_length,
+                replace_whitespace=True,
+            )
+        )[indent_length + quotes_length :]
+
+        if len(summary_lines) > 1:
+            for line in summary_lines[1:]:
+                new_summary += "\n"
+                new_summary += "\n".join(
+                    textwrap.wrap(
+                        line,
+                        width=line_length,
+                        subsequent_indent=" " * indent_length,
+                        replace_whitespace=True,
+                    )
+                )
+
+        return new_summary
+
+
 class ClosingQuotesFormatter(StringFormatter):
     """Fix the position of the closing quotes."""
 
@@ -77,57 +138,36 @@ class ClosingQuotesFormatter(StringFormatter):
         return new_string
 
 
-class FinalPeriodFormatter(StringAndQuotesFormatter):
+class FinalPeriodFormatter(SummaryFormatter):
     """Add a period to the end of single line docstrings and summaries."""
 
     name = "final-period"
     END_OF_SENTENCE_PUNCTUATION = {".", "?", "!", "‽", ":", ";"}
 
-    def _treat_string(
+    def _treat_summary(
         self,
-        tokeninfo: tokenize.TokenInfo,
-        _: int,
-        quotes: str,
+        summary: str,
+        indent_length: int,
         quotes_length: Literal[1, 3],
+        description_exists: bool,
     ) -> str:
         """Add a period to the end of single-line docstrings and summaries."""
-        # Handle single line docstrings
-        if not tokeninfo.string.count("\n"):
-            if (
-                tokeninfo.string[-quotes_length - 1]
-                not in self.END_OF_SENTENCE_PUNCTUATION
-            ):
-                return tokeninfo.string[:-quotes_length] + "." + quotes
-        # Handle multi-line docstrings
-        else:
-            lines = tokeninfo.string.splitlines()
-            # If second line is one recurring character we're dealing with a rst title
-            if (stripped := lines[1].lstrip()) and stripped.count(stripped[0]) == len(
-                stripped
-            ):
-                return tokeninfo.string
-            # If second line is empty we're dealing with a summary
-            if lines[1] == "":
-                if lines[0][-1] not in self.END_OF_SENTENCE_PUNCTUATION:
-                    return lines[0] + ".\n" + "\n".join(lines[1:])
-            # TODO(#26): Handle multi-line docstrings that do not have a summary
-            # This is obviously dependent on whether 'pydocstringformatter' will
-            # start enforcing summaries :)
-        return tokeninfo.string
+        if summary[-1] in self.END_OF_SENTENCE_PUNCTUATION:
+            return summary
+
+        if _utils.is_rst_title(summary):
+            return summary
+
+        return summary + "."
 
 
 class SplitSummaryAndDocstringFormatter(SummaryFormatter):
     """Split the summary and body of a docstring based on a period and max length.
 
     The maximum length of a summary can be set with the --max-summary-lines option.
-
-    This formatter is currently optional as its considered somwehat opinionated
-    and might require major refactoring for existing projects.
     """
 
     name = "split-summary-body"
-    # TODO(#68): Make this non-optional
-    optional = True
 
     end_of_sentence_period = re.compile(
         r"""
@@ -140,15 +180,24 @@ class SplitSummaryAndDocstringFormatter(SummaryFormatter):
     """Pattern to match against an end of sentence period."""
 
     # pylint: disable-next=too-many-branches
-    def _treat_summary(self, summary: str, indent_length: int) -> str:
+    def _treat_summary(
+        self,
+        summary: str,
+        indent_length: int,
+        quotes_length: Literal[1, 3],
+        description_exists: bool,
+    ) -> str:
         """Split a summary and body if there is a period after the summary."""
         new_summary = None
 
+        if _utils.is_rst_title(summary):
+            return summary
+
         # Try to split on period
         if match := re.search(self.end_of_sentence_period, summary):
             index = match.start()
 
-            if summary[: index - 1].count("\n") < self.config.max_summary_lines:
+            if summary[:index].count("\n") < self.config.max_summary_lines:
                 if len(summary) == index + 1:
                     new_summary = summary
 
@@ -161,29 +210,17 @@ class SplitSummaryAndDocstringFormatter(SummaryFormatter):
                     )
 
                 # Handle summaries that end with a period and a direct new line
-                # but not a double new line.
                 elif summary[index + 1] == "\n":
-                    # If this is the end of the docstring, don't do anything
-                    if summary[index + 2 :] == indent_length * " ":
-                        new_summary = summary
-                    # Split between period and rest of docstring
-                    else:
-                        new_summary = summary[:index] + ".\n\n" + summary[index + 2 :]
+                    new_summary = summary[:index] + ".\n\n" + summary[index + 2 :]
 
         # Try to split on max length
         if not new_summary and summary.count("\n") > self.config.max_summary_lines - 1:
             lines = summary.splitlines()
-            new_summary = "\n".join(lines[: self.config.max_summary_lines])
-
-            # Handle summaries without any additional text beyond max lines
-            if lines[self.config.max_summary_lines] == indent_length * " ":
-                new_summary += "\n" + lines[self.config.max_summary_lines]
-
-            # Split between max lines and rest of docstring
-            else:
-                new_summary += "\n\n" + "\n".join(
-                    lines[self.config.max_summary_lines :]
-                )
+            new_summary = (
+                "\n".join(lines[: self.config.max_summary_lines])
+                + "\n\n"
+                + "\n".join(lines[self.config.max_summary_lines :])
+            )
 
         return new_summary or summary
 
@@ -202,17 +239,35 @@ class StripWhitespacesFormatter(StringAndQuotesFormatter):
     ) -> str:
         """Strip whitespaces."""
         lines = tokeninfo.string[quotes_length:-quotes_length].split("\n")
-        for index, line in enumerate(lines):
-            if index == 0:  # pylint: disable=compare-to-zero
-                lines[index] = line.lstrip().rstrip()
-            elif index == len(lines) - 1:
-                # Remove whitespaces if last line is completely empty
-                if len(line) > indent_length and line.count(" ") == len(line):
-                    lines[index] = ""
-            else:
-                lines[index] = line.rstrip()
+        new_lines: list[str] = []
 
-        return quotes + "\n".join(lines) + quotes
+        for index, line in enumerate(lines):
+            if line == "":
+                # Remove double white lines
+                if index and lines[index - 1] == "":
+                    continue
+
+            # On the first line strip from both sides
+            if index == 0:  # pylint: disable=compare-to-zero
+                new_lines.append(line.lstrip().rstrip())
+
+            # Check last line
+            elif index == len(lines) - 1:
+                # If completely whitespace, just return the indent_length
+                if line.count(" ") == len(line):
+                    new_lines.append(indent_length * " ")
+                else:
+                    new_lines.append(line)
+
+            # Else, only strip right side
+            else:
+                new_lines.append(line.rstrip())
+
+        # Remove a final white line
+        if len(new_lines) > 3 and new_lines[-2] == "":
+            new_lines.pop(-2)
+
+        return quotes + "\n".join(new_lines) + quotes
 
 
 class QuotesTypeFormatter(StringAndQuotesFormatter):
