@@ -6,7 +6,7 @@ from pydocstringformatter.utils.exceptions import (
 from pydocstringformatter.utils.file_diference import _generate_diff
 from pydocstringformatter.utils.find_docstrings import _is_docstring
 from pydocstringformatter.utils.find_python_file import _find_python_files
-from pydocstringformatter.utils.output import _print_to_console
+from pydocstringformatter.utils.output import _print_to_console, _sys_exit
 
 __all__ = [
     "_find_python_files",
@@ -16,4 +16,5 @@ __all__ = [
     "PydocstringFormatterError",
     "TomlParsingError",
     "_print_to_console",
+    "_sys_exit",
 ]
